% 1 Nov 2017 Porto 
% Alper Cenesiz & Luis Guimaraes
%%
matlabrc
clc;
%-------------------------------------------------------------------------%
%Step 1: Import Data
%-------------------------------------------------------------------------%
% Data starts at 1965Q3
% Data ends at 2016Q2
yx1=load('Nominal Consumer Durables Expenditure.txt');
yx2=load('Nominal Residential Investment.txt');
yc1=load('Nominal Consumer Nondurables Expenditure.txt');
yc2=load('Nominal Services.txt');

px1=load('Implicit Price Index of Consumer Durables Expenditure.txt');
px2=load('Implicit Price Index of Residential Investment.txt');
pc1=load('Implicit Price Index of Consumer Nondurables Expenditure.txt');
pc2=load('Implicit Price Index of Services.txt');

r=load('Federal Funds Rate.txt');
w=load('Real Compensation per Hour in the Nonfarm Business Sector.txt');
ci=load('CRB Commodity Spot Price Index.txt');
%%
%-------------------------------------------------------------------------%
%Step 2: Tornqvist Indices
%-------------------------------------------------------------------------%

% Real expenditures:
yxr1=yx1./px1;
yxr2=yx2./px2;
ycr1=yc1./pc1;
ycr2=yc2./pc2;

% Normalize first entry to 1
yx(1)=1;
px(1)=1;
yc(1)=1;
pc(1)=1;

for i=2:size(yc1,1);    
    g(i)=exp(...
    (yx1(i)/(yx1(i)+yx2(i))+yx1(i-1)/(yx1(i-1)+yx2(i-1)))*...
    1/2*log(yxr1(i)/yxr1(i-1))+...
    (yx2(i)/(yx1(i)+yx2(i))+yx2(i-1)/(yx1(i-1)+yx2(i-1)))*...
    1/2*log(yxr2(i)/yxr2(i-1)));
    yx(i,1)=g(i)*yx(i-1);
end;
clear g

for i=2:size(yx1,1);    
    g(i)=...
    exp((yx1(i)/(yx1(i)+yx2(i))+yx1(i-1)/(yx1(i-1)+yx2(i-1)))*...
    1/2*log(px1(i)/px1(i-1))+...
    (yx2(i)/(yx1(i)+yx2(i))+yx2(i-1)/(yx1(i-1)+yx2(i-1)))*...
    1/2*log(px2(i)/px2(i-1)));
    px(i,1)=g(i)*px(i-1);
end;
clear yxr1 yxr2 yx1 yx2 px1 px2 g;

for i=2:size(yc1,1);    
    g(i)=...
    exp((yc1(i)/(yc1(i)+yc2(i))+yc1(i-1)/(yc1(i-1)+yc2(i-1)))*...
    1/2*log(ycr1(i)/ycr1(i-1))+...
    (yc2(i)/(yc1(i)+yc2(i))+yc2(i-1)/(yc1(i-1)+yc2(i-1)))*...
    1/2*log(ycr2(i)/ycr2(i-1)));
    yc(i,1)=g(i)*yc(i-1);
end;
clear g

for i=2:size(yc1,1);    
    g(i)=...
    exp((yc1(i)/(yc1(i)+yc2(i))+yc1(i-1)/(yc1(i-1)+yc2(i-1)))*...
    1/2*log(pc1(i)/pc1(i-1))+...
    (yc2(i)/(yc1(i)+yc2(i))+yc2(i-1)/(yc1(i-1)+yc2(i-1)))*...
    1/2*log(pc2(i)/pc2(i-1)));
    pc(i,1)=g(i)*pc(i-1);
end;
clear g ycr1 ycr2 ycr3 yc1 yc2 yc3 pc1 pc2 pc3;

%%
%-------------------------------------------------------------------------%
%Step 5: Save Data Input
%-------------------------------------------------------------------------%
clearvars -except yx yc px pc w r ci

filename='varinput';
X=[yx yc px pc w ci]; 
X=log(X);
X=[X r];
A={'yx', 'yc', 'px', 'pc', 'w', 'ci','r'};
for ix=1:size(X,2)
for ix2=1:size(X,1)
A{ix2+1,ix}=X(ix2,ix);
end
end
xlswrite(filename,A);
